import React, { ElementType, HTMLAttributes, RefObject } from 'react';
import { Placements } from '../Types';
export type Directions = 'start' | 'end';
export type Breakpoints = {
    xs: Directions;
} | {
    sm: Directions;
} | {
    md: Directions;
} | {
    lg: Directions;
} | {
    xl: Directions;
} | {
    xxl: Directions;
};
export type Alignments = Directions | Breakpoints;
export interface CDropdownProps extends HTMLAttributes<HTMLDivElement | HTMLLIElement> {
    /**
     * Set aligment of dropdown menu.
     *
     * @type 'start' | 'end' | { xs: 'start' | 'end' } | { sm: 'start' | 'end' } | { md: 'start' | 'end' } | { lg: 'start' | 'end' } | { xl: 'start' | 'end'} | { xxl: 'start' | 'end'}
     */
    alignment?: Alignments;
    /**
     * Configure the auto close behavior of the dropdown:
     * - `true` - the dropdown will be closed by clicking outside or inside the dropdown menu.
     * - `false` - the dropdown will be closed by clicking the toggle button and manually calling hide or toggle method. (Also will not be closed by pressing esc key)
     * - `'inside'` - the dropdown will be closed (only) by clicking inside the dropdown menu.
     * - `'outside'` - the dropdown will be closed (only) by clicking outside the dropdown menu.
     */
    autoClose?: 'inside' | 'outside' | boolean;
    /**
     * A string of all className you want applied to the base component.
     */
    className?: string;
    /**
     * Component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: string | ElementType;
    /**
     * Sets a darker color scheme to match a dark navbar.
     */
    dark?: boolean;
    /**
     * Sets a specified  direction and location of the dropdown menu.
     */
    direction?: 'center' | 'dropup' | 'dropup-center' | 'dropend' | 'dropstart';
    /**
     * Callback fired when the component requests to be hidden.
     */
    onHide?: () => void;
    /**
     * Callback fired when the component requests to be shown.
     */
    onShow?: () => void;
    /**
     * Describes the placement of your component after Popper.js has applied all the modifiers that may have flipped or altered the originally provided placement property.
     *
     * @type 'auto' | 'top-end' | 'top' | 'top-start' | 'bottom-end' | 'bottom' | 'bottom-start' | 'right-start' | 'right' | 'right-end' | 'left-start' | 'left' | 'left-end'
     */
    placement?: Placements;
    /**
     * If you want to disable dynamic positioning set this property to `true`.
     */
    popper?: boolean;
    /**
     * Set the dropdown variant to an btn-group, dropdown, input-group, and nav-item.
     */
    variant?: 'btn-group' | 'dropdown' | 'input-group' | 'nav-item';
    /**
     * Toggle the visibility of dropdown menu component.
     */
    visible?: boolean;
}
interface ContextProps extends CDropdownProps {
    dropdownToggleRef: RefObject<any> | undefined;
    setVisible: React.Dispatch<React.SetStateAction<boolean | undefined>>;
}
export declare const CDropdownContext: React.Context<ContextProps>;
export declare const CDropdown: React.ForwardRefExoticComponent<CDropdownProps & React.RefAttributes<HTMLDivElement | HTMLLIElement>>;
export {};
